@@ -27,7 +27,7 @@ gettext.textdomain('kwplayer')
 _ = gettext.gettext
 
 APPNAME = _('KW Player')
-VERSION = '3.2.6'
+VERSION = '3.2.7'
 HOMEPAGE = 'https://github.com/LiuLang/kwplayer'
 AUTHORS = ['LiuLang <gsushzhsosgsu@gmail.com>', ]
 DESCRIPTION = _('A simple music player on Linux desktop.')
@@ -125,17 +125,20 @@ def check_first():
 
 def mig_5_6(conf):
     '''Merge configuration from v3.2.5 to 3.2.6'''
-    shutil.copy(PLS_JSON, PLS_JSON + '.bak')
-    with open(PLS_JSON) as fh:
-        pls = json.loads(fh.read())
-    cached = pls['_names_'][0]
-    if cached[1] == 'Cached':
-        pls['_names_'] = pls['_names_'][1:]
-        with open(PLS_JSON, 'w') as fh:
-            fh.write(json.dumps(pls))
+    if os.path.exists(PLS_JSON):
+        shutil.copy(PLS_JSON, PLS_JSON + '.bak')
+        with open(PLS_JSON) as fh:
+            pls = json.loads(fh.read())
 
-    conf['version'] = VERSION
-    dump_conf(conf)
+        cached = pls['_names_'][0]
+        if cached[1] == 'Cached':
+            pls['_names_'] = pls['_names_'][1:]
+            with open(PLS_JSON, 'w') as fh:
+                fh.write(json.dumps(pls))
+
+    if 'version' not in conf:
+        conf['version'] = VERSION
+        dump_conf(conf)
     return conf
 
 def load_conf():
@@ -145,8 +148,7 @@ def load_conf():
         for key in _default_conf:
             if key not in conf:
                 conf[key] = _default_conf[key]
-        #if 'version' not in conf:
-        #    conf = mig_5_6(conf)
+        # will removed in 3.2.8
         conf = mig_5_6(conf)
         return conf
     dump_conf(_default_conf)
